;;; site-gentoo.el --- site initialisation for Gentoo-installed packages

;;; Commentary:
;; Automatically generated by elisp-common.eclass
;; DO NOT EDIT THIS FILE

;;; Code:

;;; emacs-daemon site-lisp configuration

;; Copyright 2008-2016 Gentoo Foundation
;; Distributed under the terms of the GNU General Public License v2 or later

(and
 (fboundp 'daemonp)
 (daemonp)
 (null after-init-time)
 (let* ((file (concat "/var/run/emacs/" (user-login-name) "/emacs.pid"))
	(pid (if (file-readable-p file)
		 ;; Get process id from file
		 (with-temp-buffer
		   (ignore-errors
		    (insert-file-contents-literally file nil 0 100)
		    (and (looking-at "[0-9]+")
			 (string-to-number (match-string 0))))))))
   (cond
    ((and (integerp pid)
	  (string-match
	   "emacs" (or (cdr (assq 'comm (process-attributes pid))) ""))
	  (/= pid (emacs-pid)))
     ;; If another Emacs daemon is already running for this user,
     ;; then we would steal its server socket. So we better die.
     (message "Another Emacs daemon is already running at process id %d" pid)
     (kill-emacs))
    ((file-writable-p file)
     ;; Write process id to file
     (with-temp-file file
       (insert (number-to-string (emacs-pid)) "\n"))
     ;; Remove file on exit
     (add-hook 'kill-emacs-hook
	       `(lambda () (ignore-errors (delete-file ,file))))))
   ;; Restart the server if signal SIGUSR1 is received.
   (define-key special-event-map [sigusr1] 'server-start)))

;;; emacs-23 site-lisp configuration

(when (string-match "\\`23\\.4\\>" emacs-version)
  (let ((path (getenv "INFOPATH"))
	(dir "/usr/share/info/emacs-23")
	(re "\\`/usr/share/info\\>"))
    (and path
	 ;; move Emacs Info dir before anything else in /usr/share/info
	 (let* ((p (cons nil (split-string path ":" t))) (q p))
	   (while (and (cdr q) (not (string-match re (cadr q))))
	     (setq q (cdr q)))
	   (setcdr q (cons dir (delete dir (cdr q))))
	   (setq Info-directory-list (prune-directory-list (cdr p)))))))

;;; emacs-24 site-lisp configuration

(when (string-match "\\`24\\.5\\>" emacs-version)
  (let ((path (getenv "INFOPATH"))
	(dir "/usr/share/info/emacs-24")
	(re "\\`/usr/share/info\\>"))
    (and path
	 ;; move Emacs Info dir before anything else in /usr/share/info
	 (let* ((p (cons nil (split-string path ":" t))) (q p))
	   (while (and (cdr q) (not (string-match re (cadr q))))
	     (setq q (cdr q)))
	   (setcdr q (cons dir (delete dir (cdr q))))
	   (setq Info-directory-list (prune-directory-list (cdr p)))))))

;;; emacs-25 site-lisp configuration

(when (string-match "\\`25\\.3\\>" emacs-version)
  (let ((path (getenv "INFOPATH"))
	(dir "/usr/share/info/emacs-25")
	(re "\\`/usr/share/info\\>"))
    (and path
	 ;; move Emacs Info dir before anything else in /usr/share/info
	 (let* ((p (cons nil (split-string path ":" t))) (q p))
	   (while (and (cdr q) (not (string-match re (cadr q))))
	     (setq q (cdr q)))
	   (setcdr q (cons dir (delete dir (cdr q))))
	   (setq Info-directory-list (prune-directory-list (cdr p)))))))

;;; emacs-26 site-lisp configuration

(when (string-match "\\`26\\.3\\>" emacs-version)
  (let ((path (getenv "INFOPATH"))
	(dir "/usr/share/info/emacs-26")
	(re "\\`/usr/share\\>"))
    (and path
	 ;; move Emacs Info dir before anything else in /usr/share
	 (let* ((p (cons nil (split-string path ":" t))) (q p))
	   (while (and (cdr q) (not (string-match re (cadr q))))
	     (setq q (cdr q)))
	   (setcdr q (cons dir (delete dir (cdr q))))
	   (setq Info-directory-list (prune-directory-list (cdr p)))))))

;;; analog site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/analog")
(autoload 'analog "analog" "Start analog mode" t)

;;; apache-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/apache-mode")
(autoload 'apache-mode "apache-mode" "autoloaded" t)
(add-to-list 'auto-mode-alist '("\\.htaccess$"   . apache-mode))
(add-to-list 'auto-mode-alist '("httpd\\.conf$"  . apache-mode))
(add-to-list 'auto-mode-alist '("srm\\.conf$"    . apache-mode))
(add-to-list 'auto-mode-alist '("access\\.conf$" . apache-mode))
(add-to-list 'auto-mode-alist '("apache[12]\?\\.conf$" . apache-mode))
(add-to-list 'auto-mode-alist '("commonapache[12]\?\\.conf$" . apache-mode))

;;; apel site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/apel")

;;; async site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/async")
(load "/usr/share/emacs/site-lisp/async/async-autoloads" nil t)

;;; auctex site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/auctex")
(require 'tex-site)

;; detect needed steps after rebuild
(setq TeX-parse-self t)

;;; auto-complete site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/auto-complete")
(autoload 'auto-complete-mode "auto-complete" "AutoComplete mode" t)
(setq ac-dictionary-directories "/usr/share/emacs/etc/auto-complete/dict")

;;; autoconf-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/autoconf-mode")
(autoload 'autoconf-mode "autoconf-mode"
  "Major mode for editing autoconf files." t)
(autoload 'autotest-mode "autotest-mode"
  "Major mode for editing autotest files." t)
(add-to-list 'auto-mode-alist
	     '("\\.ac\\'\\|configure\\.in\\'" . autoconf-mode))
(add-to-list 'auto-mode-alist
	     '("\\.at\\'" . autotest-mode))

;;; bbdb site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/bbdb")
(require 'bbdb-loaddefs)
;; t indicates that bbdb.sty is in the regular TeX search path
(setq bbdb-tex-path t)

;;; binclock site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/binclock")
(autoload 'binclock "binclock" "Display the binary clock." t)

;;; blogmax site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/blogmax")
(autoload 'weblog-mode "blogmax" "Weblog" t)
(autoload 'weblog-set-buffer-mode "blogmax"
  "Set the mode to weblog-mode for text files in the *weblog-directory*" t)

;;; bm site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/bm")
(autoload 'bm-toggle "bm" "Toggle bookmark in current buffer." t)
(autoload 'bm-next "bm" "Goto bookmark." t)
(autoload 'bm-previous "bm" "Goto previous bookmark." t)

;;; bongo site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/bongo")
(if (boundp 'image-load-path)
    (add-to-list 'image-load-path "/usr/share/emacs/etc/bongo" t))
(autoload 'bongo "bongo" "Start Bongo by switching to a Bongo buffer." t)

;;; boxquote site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/boxquote")
(load "boxquote-autoloads" nil t)

;;; browse-kill-ring site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/browse-kill-ring")
(autoload 'browse-kill-ring "browse-kill-ring"
  "Display items in the `kill-ring' in another buffer." t)
(autoload 'browse-kill-ring-default-keybindings "browse-kill-ring"
  "Set up M-y (`yank-pop') so that it can invoke `browse-kill-ring'." t)

;;; bubblet site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/bubblet")
(autoload 'bubblet "bubblet" "Start a new Bubblet game." t)

;;; calfw site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/calfw")
(autoload 'cfw:open-calendar-buffer "calfw" "Open a calendar buffer simply." t)

;;; chess site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/chess")

(autoload 'chess "chess"
  "Start a game of chess, playing against ENGINE (a module name)." t)
(defalias 'chess-session 'chess)
(autoload 'chess-create-display "chess"
  "Create a display, letting the user's customization decide the style.")
(autoload 'chess-link "chess-link"
  "Play out a game between two engines, and watch the progress." t)
(autoload 'chess-pgn-read "chess-pgn"
  "Read and display a PGN game after point." t)
(autoload 'chess-pgn-mode "chess-pgn"
  "A mode for editing chess PGN files." t)
(defalias 'pgn-mode 'chess-pgn-mode)
(autoload 'chess-puzzle "chess-puzzle"
  "Pick a random puzzle from FILE, and solve it against the default engine." t)
(autoload 'chess-fischer-random-position "chess-random"
  "Generate a Fischer Random style position.")
(autoload 'chess-tutorial "chess-tutorial"
  "A simple chess training display." t)
(autoload 'chess-ics "chess-ics"
  "Connect to an Internet Chess Server." t)

(add-to-list 'auto-mode-alist '("\\.pgn\\'" . chess-pgn-mode))

(setq chess-images-directory "/usr/share/emacs/etc/chess/pieces/xboard")
(setq chess-sound-directory "/usr/share/emacs/etc/chess/sounds")
(setq chess-eco-hash-table "/usr/share/emacs/etc/chess/chess-eco.fen")
(setq chess-polyglot-book-file "/usr/share/emacs/etc/chess/chess-polyglot.bin")

;; Change the order of the engine preference list to coincide with
;; the order of dependencies in the ebuild. The user can override this
;; using "M-x customize-group RET chess RET".
(setq chess-default-engine
      '(chess-stockfish chess-fruit chess-gnuchess chess-phalanx chess-sjeng
	chess-crafty chess-ai))

;;; circe site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/circe")
(autoload 'circe "circe" "Connect to IRC." t)

;;; cldoc site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/cldoc")

(autoload 'cldoc-mode "cldoc" nil t)
(autoload 'turn-on-cldoc-mode "cldoc" nil t)
(add-hook 'lisp-mode-hook 'turn-on-cldoc-mode)

(add-hook 'slime-repl-mode-hook
          #'(lambda ()
              (turn-on-cldoc-mode)
              (define-key slime-repl-mode-map " " nil)))
(add-hook 'slime-mode-hook
          #'(lambda () (define-key slime-mode-map " " nil)))
(setq slime-use-autodoc-mode nil)

;;; color-moccur site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/color-moccur")
(mapc (function (lambda (x) (autoload x "color-moccur" nil t)))
      '(moccur
	dmoccur
	dired-do-moccur
	Buffer-menu-moccur
	grep-buffers
	search-buffers
	occur-by-moccur
	isearch-moccur
	moccur-grep
	moccur-grep-find))

;;; color-theme site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/color-theme")

(autoload (quote color-theme-select) "color-theme" "\
Displays a special buffer for selecting and installing a color theme.
With optional prefix ARG, this buffer will include color theme libraries
as well.  A color theme library is in itself not complete, it must be
used as part of another color theme to be useful.  Thus, color theme
libraries are mainly useful for color theme authors." t nil)

(autoload (quote color-theme-describe) "color-theme" "\
Describe color theme listed at point.
This shows the documentation of the value of text-property color-theme
at point.  The text-property color-theme should be a color theme
function.  See `color-themes'." t nil)

(autoload (quote color-theme-install-at-mouse) "color-theme" "\
Install color theme clicked upon using the mouse.
First argument EVENT is used to set point.  Then
`color-theme-install-at-point' is called." t nil)

(autoload (quote color-theme-install-at-point-for-current-frame) "color-theme" "\
Install color theme at point for current frame only.
Binds `color-theme-is-global' to nil and calls
`color-theme-install-at-point'." t nil)

(autoload (quote color-theme-print) "color-theme" "\
Print the current color theme function.

You can contribute this function to <URL:news:gnu.emacs.sources> or
paste it into your .emacs file and call it.  That should recreate all
the settings necessary for your color theme.

Example:

    (require 'color-theme)
    (defun my-color-theme ()
      \"Color theme by Alex Schroeder, created 2000-05-17.\"
      (interactive)
      (color-theme-install
       '(...
	 ...
	 ...)))
    (my-color-theme)

If you want to use a specific color theme function, you can call the
color theme function in your .emacs directly.

Example:

    (require 'color-theme)
    (color-theme-gnome2)" t nil)

(autoload (quote color-theme-analyze-defun) "color-theme" "\
Once you have a color-theme printed, check for missing faces.
This is used by maintainers who receive a color-theme submission
and want to make sure it follows the guidelines by the color-theme
author." t nil)

(autoload (quote color-theme-make-snapshot) "color-theme" "\
Return the definition of the current color-theme.
The function returned will recreate the color-theme in use at the moment." nil nil)

(autoload (quote color-theme-compare) "color-theme" "\
Compare two color themes.
This will print the differences between installing THEME-A and
installing THEME-B.  Note that the order is important: If a face is
defined in THEME-A and not in THEME-B, then this will not show up as a
difference, because there is no reset before installing THEME-B.  If a
face is defined in THEME-B and not in THEME-A, then this will show up as
a difference." t nil)

(autoload (quote color-theme-install) "color-theme" "\
Install a color theme defined by frame parameters, variables and faces.

The theme is installed for all present and future frames; any missing
faces are created.  See `color-theme-install-faces'.

THEME is a color theme definition.  See below for more information.

If you want to install a color theme from your .emacs, use the output
generated by `color-theme-print'.  This produces color theme function
which you can copy to your .emacs.

A color theme definition is a list:
\([FUNCTION] FRAME-PARAMETERS VARIABLE-SETTINGS FACE-DEFINITIONS)

FUNCTION is the color theme function which called `color-theme-install'.
This is no longer used.  There was a time when this package supported
automatic factoring of color themes.  This has been abandoned.

FRAME-PARAMETERS is an alist of frame parameters.  These are installed
with `color-theme-install-frame-params'.  These are installed last such
that any changes to the default face can be changed by the frame
parameters.

VARIABLE-DEFINITIONS is an alist of variable settings.  These are
installed with `color-theme-install-variables'.

FACE-DEFINITIONS is an alist of face definitions.  These are installed
with `color-theme-install-faces'.

If `color-theme-is-cumulative' is nil, a color theme will undo face and
frame-parameter settings of previous color themes." nil nil)

(autoload (quote color-theme-submit) "color-theme" "\
Submit your color-theme to the maintainer." t nil)

(autoload (quote color-theme-initialize) "color-theme" "\
Initialize the color theme package by loading color-theme-libraries." t nil)

;;; company-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/company-mode")
(autoload 'company-mode "company" nil t)

;;; crontab-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/crontab-mode")
(autoload 'crontab-mode "crontab-mode" nil t)
(autoload 'crontab-get "crontab-mode" nil t)

;;; crypt++ site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/crypt++")
(require 'crypt++)

;;; css-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/css-mode")
(add-to-list 'auto-mode-alist '("\\.css\\'" . css-mode))
(autoload 'css-mode "css-mode" "Mode for editing Cascading Style Sheets" t)

;;; dash site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/dash")

;;; ddskk site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/ddskk")
(require 'skk-setup)

(setq skk-large-jisyo "/usr/share/skk/SKK-JISYO.L")

;;; develock site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/develock")
(autoload 'develock-mode "develock" "Toggle Develock mode." t)
(autoload 'turn-on-develock "develock")

;;; df-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/df-mode")
(autoload 'df-mode "df-mode" nil t)

;;; dictionary site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/dictionary")
(load "dictionary-init" nil t)

;;; dircolors site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/dircolors")
(autoload 'dircolors "dircolors" nil t)
(add-hook 'completion-list-mode-hook 'dircolors)
(add-hook 'buffer-menu-mode-hook 'dircolors)

;;; dired-sort-menu site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/dired-sort-menu")
(add-hook 'dired-load-hook
	  (lambda () (require 'dired-sort-menu)))

;;; doxymacs site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/doxymacs")
(autoload 'doxymacs-mode "doxymacs"
  "Minor mode for using/creating Doxygen documentation." t)
(autoload 'doxymacs-font-lock "doxymacs"
  "Turn on font-lock for Doxygen keywords." t)
(add-hook 'c-mode-common-hook 'doxymacs-mode)

;; optional font-lock support
;;(defun gentoo-doxymacs-font-lock-hook ()
;;  (if (or (eq major-mode 'c-mode) (eq major-mode 'c++-mode))
;;      (doxymacs-font-lock)))
;;(add-hook 'font-lock-mode-hook 'gentoo-doxymacs-font-lock-hook)

;;; dropdown-list site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/dropdown-list")
(autoload 'dropdown-list "dropdown-list")

;;; ebuild-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/ebuild-mode")
(autoload 'ebuild-mode "ebuild-mode"
  "Major mode for Portage .ebuild and .eclass files." t)
(autoload 'gentoo-newsitem-mode "gentoo-newsitem-mode"
  "Major mode for Gentoo GLEP 42 news items." t)
(autoload 'glep-mode "glep-mode"
  "Major mode for Gentoo Linux Enhancement Proposals." t)

(add-to-list 'auto-mode-alist '("\\.\\(ebuild\\|eclass\\)\\'" . ebuild-mode))
(add-to-list 'auto-mode-alist
	     '("/[0-9]\\{4\\}-[01][0-9]-[0-3][0-9]-.+\\.[a-z]\\{2\\}\\.txt\\'"
	       . gentoo-newsitem-mode))
(add-to-list 'auto-mode-alist '("/glep.*\\.rst\\'" . glep-mode))
(add-to-list 'interpreter-mode-alist '("openrc-run" . sh-mode))
(add-to-list 'interpreter-mode-alist '("runscript" . sh-mode))
(modify-coding-system-alist 'file "\\.\\(ebuild\\|eclass\\)\\'" 'utf-8)

;;; edb site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/edb")
(autoload 'db-find-file "database" "EDB database package" t)
(autoload 'edb-interact "database" "EDB database package" t)
(defalias 'edb-EXPERIMENTAL-interact 'edb-interact)

;;; edit-list site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/edit-list")
(autoload 'edit-list "edit-list"
  "Edit a list called LIST-NAME interactively." t)

;;; elscreen site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/elscreen")
(autoload 'elscreen-start "elscreen" nil t)

;;; emacs-jabber site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/emacs-jabber")
(autoload 'jabber-customize "jabber" "customize jabber options" t)
(autoload 'jabber-connect "jabber"
  "connect to the jabber server and start a jabber xml stream" t)

;;; emacs-wget site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/emacs-wget")
(autoload 'wget "wget" "wget interface for Emacs." t)
(autoload 'wget-web-page "wget" "wget interface to download whole web page." t)
(add-hook 'w3m-mode-hook (lambda () (require 'w3m-wget)))

;;; emhacks site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/emhacks")

;; dir-tree
(autoload 'dir-tree "dir-tree"
  "Display the ROOT directory in a tree widget." t)

;; gdiff
(require 'gdiff-setup)

;; swbuff
(autoload 'swbuff-switch-to-next-buffer "swbuff"
  "Switch to the next buffer in the buffer list." t)
(autoload 'swbuff-kill-this-buffer "swbuff"
  "Kill the current buffer.
And update the status window if showing." t)

;; tabbar
(autoload 'tabbar-local-mode "tabbar" nil t)
(autoload 'tabbar-mode "tabbar" nil t)
(autoload 'tabbar-mwheel-mode "tabbar" nil t)

;; jjar
(autoload 'jjar-create "jjar" "Create a new jar file." t)
(autoload 'jjar-update "jjar" "Update an existing jar file." t)

;; jmaker
(autoload 'jmaker-generate-makefile "jmaker"
  "Generate and edit a Java Makefile in directory ROOT." t)

;;; emms site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/emms")
(require 'emms-auto)

;;; erobot site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/erobot")
(autoload 'erobot "erobot" "Starts a game of erobot." t)
(autoload 'erobot-tour "erobot"
  "Introduction to some of the erobots included in the package." t)

;;; ess site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/ess")
(require 'ess-site)

;;; evil site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/evil")
(autoload 'evil-mode "evil" "Toggle Evil in all buffers." t)

;;; fff site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/fff")
(autoload 'fff-find-file-in-envvar-path			"fff" nil t)
(autoload 'fff-insert-file-in-envvar-path		"fff" nil t)
(autoload 'fff-find-file-in-exec-path			"fff" nil t)
(autoload 'fff-insert-file-in-exec-path			"fff" nil t)
(autoload 'fff-find-file-in-path			"fff" nil t)
(autoload 'fff-insert-file-in-path			"fff" nil t)
(autoload 'fff-find-file-in-locate-db			"fff" nil t)
(autoload 'fff-insert-file-in-locate-db			"fff" nil t)
(autoload 'fff-install-map				"fff" nil t)
(autoload 'fff-find-emacs-lisp-library			"fff-elisp" nil t)
(autoload 'fff-insert-emacs-lisp-library		"fff-elisp" nil t)
(autoload 'fff-locate-emacs-lisp-library		"fff-elisp" nil t)
(autoload 'fff-find-loaded-elisp-function-or-variable	"fff-elisp" nil t)
(autoload 'fff-elisp-install-map			"fff-elisp" nil t)
(autoload 'fff-find-rfc					"fff-rfc" nil t)
(autoload 'fff-rfc-install-map				"fff-rfc" nil t)

;;; flashcard site-lisp configuration 

(add-to-list 'load-path "/usr/share/emacs/site-lisp/flashcard")
(add-to-list 'auto-mode-alist '("\\.deck\\'" . flashcard-mode))
(autoload 'flashcard-mode "flashcard" nil t)
(autoload 'flashcard-add-card "flashcard" nil t)
(autoload 'flashcard-import-from-colon-file "flashcard" nil t)

;;; folding site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/folding")
(autoload 'folding-mode          "folding" "Folding mode" t)
(autoload 'turn-off-folding-mode "folding" "Folding mode" t)
(autoload 'turn-on-folding-mode  "folding" "Folding mode" t)

;;; gnuserv site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/gnuserv")
(setq gnuserv-program "/usr/libexec/emacs/gnuserv")
;; necessary for FSF GNU Emacs only
(autoload 'gnuserv-start "gnuserv-compat"
  "Allow this Emacs process to be a server for client processes." t)

;;; google-c-style site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/google-c-style")
(autoload 'google-set-c-style "google-c-style"
  "Set the current buffer's c-style to Google C/C++ Programming Style." t)
(autoload 'google-make-newline-indent "google-c-style"
  "Sets up preferred newline behavior." t)

;;; graphviz-dot-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/graphviz-dot-mode")
(autoload 'graphviz-dot-mode "graphviz-dot-mode"
  "Major mode for the dot language." t)
(add-to-list 'auto-mode-alist '("\\.dot\\'" . graphviz-dot-mode))
(add-to-list 'auto-mode-alist '("\\.gv\\'" . graphviz-dot-mode))

;;; h4x0r site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/h4x0r")
(autoload 'h4x0r-region "h4x0r" "Convert region to h4x0r-talk." t)
(autoload 'h4x0r-buffer "h4x0r" "Convert entire buffer to h4x0r-talk." t)
(autoload 'h4x0r-word-at-point "h4x0r" nil t)

;;; haskell-mode site-lisp configuration

(load "/usr/share/emacs/site-lisp/haskell-mode/haskell-site-file" nil t)

;;; helm site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/helm")
(load "/usr/share/emacs/site-lisp/helm/helm-autoloads" nil t)

;;; hexrgb site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/hexrgb")

;;; highline site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/highline")
(load "highline-autoloads" nil t)

;;; howm site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/howm")
(autoload 'howm-menu "howm" nil t)

;;; htmlize site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/htmlize")
(autoload 'htmlize-buffer "htmlize"
  "Convert BUFFER to HTML, preserving colors and decorations." t)
(autoload 'htmlize-region "htmlize"
  "Convert the region to HTML, preserving colors and decorations." t)
(autoload 'htmlize-file "htmlize"
  "Load FILE, fontify it, convert it to HTML, and save the result." t)
(autoload 'htmlize-many-files "htmlize"
  "Convert FILES to HTML and save the corresponding HTML versions." t)
(autoload 'htmlize-many-files-dired "htmlize"
  "HTMLize dired-marked files." t)

;;; httpd site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/httpd")

;;; icicles site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/icicles")
(autoload 'icicle-mode "icicles" nil t)
(defalias 'icy-mode 'icicle-mode)

;;; igrep site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/igrep")

(autoload 'igrep "igrep"
  "*Run `grep` PROGRAM to match EXPRESSION in FILES..." t)
(autoload 'igrep-find "igrep"
  "*Run `grep` via `find`..." t)
(autoload 'igrep-visited-files "igrep"
  "*Run `grep` ... on all visited files." t)
(autoload 'dired-do-igrep "igrep"
  "*Run `grep` on the marked (or next prefix ARG) files." t)
(autoload 'dired-do-igrep-find "igrep"
  "*Run `grep` via `find` on the marked (or next prefix ARG) directories." t)
(autoload 'Buffer-menu-igrep "igrep"
  "*Run `grep` on the files visited in buffers marked with '>'." t)
(autoload 'igrep-insinuate "igrep"
  "Define `grep' aliases for the corresponding `igrep' commands." t)
(autoload 'grep "igrep"
  "*Run `grep` PROGRAM to match EXPRESSION in FILES..." t)
(autoload 'egrep "igrep"
  "*Run `egrep`..." t)
(autoload 'fgrep "igrep"
  "*Run `fgrep`..." t)
(autoload 'agrep "igrep"
  "*Run `agrep`..." t)
(autoload 'grep-find "igrep"
  "*Run `grep` via `find`..." t)
(autoload 'egrep-find "igrep"
  "*Run `egrep` via `find`..." t)
(autoload 'fgrep-find "igrep"
  "*Run `fgrep` via `find`..." t)
(autoload 'agrep-find "igrep"
  "*Run `agrep` via `find`..." t)


;;; inform-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/inform-mode")
(autoload 'inform-mode "inform-mode" "Inform editing mode." t)
(autoload 'inform-maybe-mode "inform-mode" "Inform/C header editing mode.")
(add-to-list 'auto-mode-alist '("\\.h\\'"   . inform-maybe-mode))
(add-to-list 'auto-mode-alist '("\\.inf\\'" . inform-mode))

;;; initsplit site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/initsplit")
(autoload 'initsplit-byte-compile-files "initsplit")

;;; jam-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/jam-mode")
(autoload 'jam-mode "jam-mode" "Generic mode for Jam rules files" t)
(add-to-list
 'auto-mode-alist
 '("\\(\\.jam\\|[Jj]ambase\\|[Jj]amfile\\|[Jj]amrules\\)\\'" . jam-mode))

;;; jasmin site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/jasmin")
(autoload 'jasmin-mode "jasmin"
  "Major mode for editing Jasmin Java bytecode assembler files." t)
(add-to-list 'auto-mode-alist '("\\.j\\'" . jasmin-mode))

;;; site-lisp configuration for keywiz

(add-to-list 'load-path "/usr/share/emacs/site-lisp/keywiz")
(autoload 'keywiz "keywiz" "Autoload for keywiz" t)

;;; lookup site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/lookup")
(autoload 'lookup "lookup" nil t)
(autoload 'lookup-region "lookup" nil t)
(autoload 'lookup-pattern "lookup" nil t)

;;; lua-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/lua-mode")
(autoload 'lua-mode "lua-mode" "Mode for editing Lua scripts" t)
(add-to-list 'auto-mode-alist '("\\.lua\\'" . lua-mode))
(setq lua-default-application "/usr/bin/lua")

;;; lyskom-elisp-client site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/lyskom-elisp-client")
(autoload 'lyskom "lyskom" "Start LysKOM" t)

;;; magit-popup site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/magit-popup")

;;; mailcrypt site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/mailcrypt")

;;; matlab site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/matlab")
(load "matlab-load" nil t)

;;; mew site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/mew")
(autoload 'mew "mew" nil t)
(autoload 'mew-send "mew" nil t)

(setq mew-icon-directory "/usr/share/emacs/etc/mew")
(setq mew-pop-port "pop-3")
(setq mew-imap-port "imap2")

;;; mic-paren site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/mic-paren")
(autoload 'paren-activate "mic-paren"
  "Activates mic-paren parenthesis highlighting." t)
(autoload 'paren-deactivate "mic-paren"
  "Deactivates mic-paren parenthesis highlighting" t)
(autoload 'paren-toggle-matching-paired-delimiter "mic-paren" nil t)
(autoload 'paren-toggle-matching-quoted-paren "mic-paren" nil t)
(autoload 'paren-toggle-open-paren-context "mic-paren" nil t)
(autoload 'paren-forward-sexp "mic-paren" nil t)
(autoload 'paren-backward-sexp "mic-paren" nil t)

;;; mldonkey site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/mldonkey")
(autoload 'mldonkey "mldonkey" "Run the MlDonkey interface." t)

(setq mldonkey-vd-filename-filters
      '(mldonkey-vd-filename-remove-p20
	mldonkey-vd-filename-remove-trailing-ws))

(setq mldonkey-vd-sort-functions
      '((not mldonkey-vd-sort-dl-state)
        (not mldonkey-vd-sort-dl-percent)))

(setq mldonkey-vd-sort-fin-functions
      '(mldonkey-vd-sort-dl-number))

(add-hook 'mldonkey-pause-hook 'mldonkey-vd)
(add-hook 'mldonkey-resume-hook 'mldonkey-vd)
(add-hook 'mldonkey-commit-hook 'mldonkey-vd)
(add-hook 'mldonkey-recover-temp-hook 'mldonkey-vd)

;;; mmm-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/mmm-mode")
(require 'mmm-auto)

;;; mpg123-el site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/mpg123-el")
(autoload 'mpg123 "mpg123" "A Front-end to mpg123" t)
(setq id3*put-prog "tagput")

;;; mu-cite site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/mu-cite")
(autoload 'mu-cite-original "mu-cite" nil t)
(add-hook 'mail-citation-hook (function mu-cite-original))

;;; muse site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/muse")
(require 'muse-autoloads)

;;; nagios-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/nagios-mode")
(autoload 'nagios-mode "nagios-mode"
  "Major mode for editing Nagios configuration files." t)
;;(add-to-list 'auto-mode-alist '("\\.cfg\\'" . nagios-mode))

;;; navi2ch site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/navi2ch")
(autoload 'navi2ch "navi2ch" "Navigator for 2ch for Emacs." t)

;;; ocaml-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/ocaml-mode")
(add-to-list 'auto-mode-alist '("\\.ml[iylp]?\\'" . caml-mode))
(autoload 'caml-mode "caml" "Major mode for editing Caml code." t)
(autoload 'run-caml "inf-caml" "Run an inferior Caml process." t)
(autoload 'camldebug "camldebug"
  "Run camldebug on program FILE in buffer *camldebug-FILE*." t)
(autoload 'inferior-caml-set-font-lock "caml-font")

(eval-after-load "caml" '(require 'caml-font))
(add-hook 'inferior-caml-mode-hooks 'inferior-caml-set-font-lock)

;;; org-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/org-mode")
(add-to-list 'auto-mode-alist '("\\.org\\'" . org-mode))

;;; outline-magic site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/outline-magic")

;;; paredit site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/paredit")
(autoload 'paredit-mode "paredit"
  "Minor mode for pseudo-structurally editing Lisp code." t)
(let ((turn-on-paredit-mode (lambda () (paredit-mode 1))))
  ;; some hooks: lisp-mode-hook and scheme-mode-hook are recommended
  ;; in the paredit source code
  (add-hook 'lisp-mode-hook turn-on-paredit-mode)
  (add-hook 'scheme-mode-hook turn-on-paredit-mode)
  (add-hook 'emacs-lisp-mode-hook turn-on-paredit-mode)
  (add-hook 'slime-mode-hook turn-on-paredit-mode))

;;; php-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/php-mode")
(autoload 'php-mode "php-mode" "Major mode for editing PHP code." t)
(add-to-list 'auto-mode-alist '("\\.php[s34]?\\'" . php-mode))
(add-to-list 'auto-mode-alist '("\\.phtml\\'" . php-mode))
(add-to-list 'auto-mode-alist '("\\.inc\\'" . php-mode))

;;; po-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/po-mode")
(autoload 'po-mode "po-mode" "Major mode for translators to edit PO files" t)
(or (fboundp 'po-find-file-coding-system)
    (autoload 'po-find-file-coding-system "po-compat"))

(add-to-list 'auto-mode-alist '("\\.po\\'\\|\\.po\\." . po-mode))
(modify-coding-system-alist 'file "\\.po\\'\\|\\.po\\."
			    'po-find-file-coding-system)

;;; pov-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/pov-mode")
(autoload 'pov-mode "pov-mode" "PoVray scene file mode" t)
(add-to-list 'auto-mode-alist '("\\.pov\\'" . pov-mode))
;;(add-to-list 'auto-mode-alist '("\\.inc\\'" . pov-mode))

;; Override customization variables setting various directories.
(setq pov-include-dir "/usr/share/povray/include")
(setq pov-insertmenu-location "/usr/share/emacs/etc/pov-mode/InsertMenu")
(setq pov-icons-location "/usr/share/emacs/etc/pov-mode/")

;;; proofgeneral site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/proofgeneral/generic")
(require 'proof-site)

;;; psgml site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/psgml")
(autoload 'sgml-mode "psgml" "Major mode to edit SGML files." t)
(autoload 'xml-mode "psgml" "Major mode to edit XML files." t)
(setq sgml-catalog-files '("CATALOG" "/etc/sgml/catalog"))
(setq sgml-display-char-list-filename
      "/usr/share/emacs/etc/psgml/iso88591.map")

;;; pymacs site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/pymacs")
(autoload 'pymacs-load "pymacs" nil t)
(autoload 'pymacs-eval "pymacs" nil t)
(autoload 'pymacs-apply "pymacs")
(autoload 'pymacs-call "pymacs")

;;; python-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/python-mode")

(autoload 'python-mode "python-mode" "Major mode for editing Python files." t)
(autoload 'jython-mode "python-mode" "Major mode for editing Jython files." t)
(autoload 'py-shell "python-mode"
  "Start an interactive Python interpreter in another window." t)

(add-to-list 'auto-mode-alist '("\\.py$" . python-mode))
(add-to-list 'auto-mode-alist '("\\.pyx$" . python-mode))
(add-to-list 'interpreter-mode-alist '("python" . python-mode))
(add-to-list 'interpreter-mode-alist '("jython" . jython-mode))

;;; quack site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/quack")

(autoload 'quack-scheme-mode-hookfunc "quack")
(autoload 'quack-inferior-scheme-mode-hookfunc "quack")
(autoload 'quack-pltfile-mode "quack"
  "Major mode for viewing PLT Scheme `.plt' package files." t)

(add-hook 'scheme-mode-hook 'quack-scheme-mode-hookfunc)
(add-hook 'inferior-scheme-mode-hook 'quack-inferior-scheme-mode-hookfunc)
(add-to-list 'auto-mode-alist '("\\.plt\\'" . quack-pltfile-mode))

;;; quilt-el site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/quilt-el")
(autoload 'quilt-mode "quilt"
  "Toggle quilt-mode. With positive arg, enable quilt-mode." t)
(autoload 'quilt-hook "quilt"
  "Enable quilt mode for quilt-controlled files.")
(add-hook 'find-file-hooks 'quilt-hook)
(add-hook 'after-revert-hook 'quilt-hook)

;;; qwerty site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/qwerty")
(autoload 'qwerty "qwerty"
  "Switch between QWERTY and DVORAK without changing the system keymap" t)

;;; regress site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/regress")
(autoload 'regress-insert-suite "regress" nil t)
(autoload 'regress-insert-call "regress" nil t)
(autoload 'regress-forget "regress" nil t)
(autoload 'regress "regress" nil t)

;;; remember site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/remember")

(autoload 'remember "remember" "Remember an arbitrary piece of data." t)
(autoload 'remember-region "remember" "Remember the data from BEG to END." t)
(autoload 'remember-clipboard "remember"
  "Remember the contents of the current clipboard." t)
(autoload 'remember-buffer "remember"
  "Remember the contents of the current buffer." t)

;;; rfcview site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/rfcview")
(autoload 'rfcview-mode "rfcview" nil t)
(add-to-list 'auto-mode-alist
	     '("/rfc[0-9]+\\.txt\\(\\.gz\\)?\\'" . rfcview-mode))

;;; riece site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/riece")
(autoload 'riece "riece" "Start riece." t)

;;; rnc-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/rnc-mode")
(autoload 'rnc-mode "rnc-mode")
(add-to-list 'auto-mode-alist '("\\.rnc\\'" . rnc-mode))

;;; ruby-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/ruby-mode")

(autoload 'ruby-mode "ruby-mode" "Major mode to edit ruby files." t)

(add-to-list 'auto-mode-alist '("Rakefile\\'" . ruby-mode))
(add-to-list 'auto-mode-alist '("\\.\\(rake\\|rb\\)\\'" . ruby-mode))
(add-to-list 'interpreter-mode-alist  '("ruby" . ruby-mode))

(autoload 'run-ruby "inf-ruby" "Run an inferior Ruby process" t)
(autoload 'inf-ruby-keys "inf-ruby" "Set local key defs for inf-ruby in ruby-mode")

(add-hook 'ruby-mode-hook 'inf-ruby-keys)

;;; rust-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/rust-mode")
(autoload 'rust-mode "rust-mode" nil t)
(add-to-list 'auto-mode-alist '("\\.rs\\'" . rust-mode))

;;; session site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/session")

;;; setnu site-lisp configuration 

(add-to-list 'load-path "/usr/share/emacs/site-lisp/setnu")
(autoload 'setnu-mode "setnu" "Toggle setnu-mode." t)
(autoload 'turn-on-setnu-mode "setnu" "Turn on setnu-mode." nil)

;;; sml-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/sml-mode")
(load "sml-mode-autoloads" nil t)

;;; sokoban site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/sokoban")
(autoload 'sokoban "sokoban" nil t)
(setq sokoban-level-file "/usr/share/emacs/etc/sokoban/sokoban.levels")

;;; ssh site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/ssh")
(add-to-list 'same-window-regexps "^\\*ssh-.*\\*\\(\\|<[0-9]+>\\)")
(autoload 'ssh "ssh" "Open a network login connection via `ssh'" t)

;;; stripes site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/stripes")
(autoload 'stripes-mode "stripes" "Toggle Color alternation mode." t)
(autoload 'turn-on-stripes-mode "stripes" "Turn on color alternation mode." t)

;;; sumibi site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/sumibi")
(autoload 'sumibi-mode "sumibi" nil t)
(autoload 'global-sumibi-mode "sumibi" nil t)

;;; template site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/template")
(autoload 'template-single-comment "template"
  "Decorate the comment in the current line with dashes and alike." t)
(autoload 'template-block-comment "template"
  "Decorate the current block of comment-only lines with dashes and alike." t)
(autoload 'template-update-header "template"
  "Replace old file name in header with current file name." t)
(autoload 'template-expand-template "template"
  "Expand template file TEMPLATE and insert result in current buffer." t)
(autoload 'template-new-file "template"
  "Open a new file FILE by using a TEMPLATE." t)
(autoload 'template-initialize "template"
  "Initialized package template.  See variable `template-initialize'." t)

(setq template-default-directories
      (list (if (and (not (file-directory-p "~/.templates/"))
		     (file-directory-p "~/lib/templates"))
		(expand-file-name "~/lib/templates/")
	      (expand-file-name "~/.templates/"))
	    "/usr/share/emacs/etc/template/templates"))

;;; tempo-snippets site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/tempo-snippets")
(autoload 'tempo-define-snippet "tempo-snippets")

;;; thinks site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/thinks")

(autoload (quote thinks) "thinks" "\
Insert TEXT wrapped in a think bubble.

Prefix a call to this function with \\[universal-argument] if you don't want
the text to be filled for you.

\(fn TEXT)" t nil)

(autoload (quote thinks-region) "thinks" "\
Bubble wrap region bounding START and END.

Prefix a call to this function with \\[universal-argument] if you don't want
the text to be filled for you.

\(fn START END)" t nil)

(autoload (quote thinks-yank) "thinks" "\
Do a `yank' and bubble wrap the yanked text.

Prefix a call to this function with \\[universal-argument] if you don't want
the text to be filled for you.

\(fn)" t nil)

(autoload (quote thinks-maybe-region) "thinks" "\
If region is active, bubble wrap region bounding START and END.
If not, query for text to insert in bubble.

\(fn)" t nil)

;;; tuareg-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/tuareg-mode")
(autoload 'tuareg-mode "tuareg" "Major mode for editing Caml code" t)
(autoload 'tuareg-run-ocaml "tuareg" "Run an OCaml toplevel process." t)
(autoload 'ocamldebug "ocamldebug" "Run the Caml debugger" t)
(defalias 'camldebug 'ocamldebug)
(add-to-list 'auto-mode-alist '("\\.ml[iylp]?\\'" . tuareg-mode))

;;; typing site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/typing")
(autoload 'typing-of-emacs "typing" "Play the game The Typing Of Emacs." t)

;;; uboat site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/uboat")
(autoload 'uboat-death-message "uboat" nil t)

;;; undo-tree site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/undo-tree")
(autoload 'undo-tree-mode "undo-tree" "Enable undo-trees" t)
(autoload 'global-undo-tree-mode "undo-tree" "Enable undo-trees globally" t)

;;; uptimes site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/uptimes")

;;; vhdl-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/vhdl-mode")
(autoload 'vhdl-mode "vhdl-mode" "VHDL Mode" t)
(add-to-list 'auto-mode-alist '("\\.vhdl?\\'" . vhdl-mode))

;;; vm site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/vm")
(require 'vm-autoloads)

;;; volume site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/volume")
(autoload 'volume "volume" "Tweak your sound card volume." t)

;;; wanderlust site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/wl")

(autoload 'wl "wl" "Wanderlust" t)
(autoload 'wl-other-frame "wl" "Wanderlust on new frame." t)
(autoload 'wl-draft "wl-draft" "Write draft with Wanderlust." t)

(setq wl-icon-directory "/usr/share/emacs/etc/wl/icons")

;;; wgrep site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/wgrep")

;;; whine site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/whine")
(autoload 'whinify "whine"
  "Make certain global-mode keys whine.
The command `unwhinify' makes them normal again." t)

;;; wikipedia-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/wikipedia-mode")

(autoload 'wikipedia-mode "wikipedia-mode"
  "Major mode for editing documents in Wikipedia markup." t)

(add-to-list 'auto-mode-alist '("\\.wiki\\'" . wikipedia-mode))
(add-to-list 'auto-mode-alist '("/[a-z]+\\.wikipedia\\.org" . wikipedia-mode))

;;; with-editor site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/with-editor")

;;; xclip site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/xclip")
(autoload 'xclip-mode "xclip"
  "Minor mode to use the `xclip' program to copy&paste." t)

;;; xrdb-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/xrdb-mode")
(autoload 'xrdb-mode "xrdb-mode" "Major mode for editing xrdb config files." t)
(add-to-list
 'auto-mode-alist
 '("\\.\\(Xdefaults\\|Xenvironment\\|Xresources\\|ad\\)\\'" . xrdb-mode))

;;; xslide site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/xslide")
(autoload 'xsl-mode "xslide" "Major mode for XSL stylesheets." t)
;; Turn on font lock when in XSL mode
(add-hook 'xsl-mode-hook
	  'turn-on-font-lock)
(add-to-list 'auto-mode-alist
	     '("\\.fo\\'\\|\\.xsl\\'" . xsl-mode))

;;; yaml-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/yaml-mode")
(autoload 'yaml-mode "yaml-mode" "Simple mode to edit YAML." t)
(add-to-list 'auto-mode-alist '("\\.\\(e?ya?\\|ra\\)ml\\'" . yaml-mode))

;;; yasnippet site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/yasnippet")
(autoload 'yas-minor-mode "yasnippet" "Toggle YASnippet mode." t)
(autoload 'yas-global-mode "yasnippet" nil t)
(autoload 'snippet-mode "yasnippet" "A mode for editing yasnippets" t)

;; YaTeX-mode
(setq auto-mode-alist
      (cons (cons "\\.tex$" 'yatex-mode) auto-mode-alist))
(autoload 'yatex-mode "yatex" "Yet Another LaTeX mode" t)

;; YaHtml-mode
(setq auto-mode-alist
      (cons (cons "\\.html$" 'yahtml-mode) auto-mode-alist))
(autoload 'yahtml-mode "yahtml" "Yet Another HTML mode" t)

;; If your Kanji code is EUC-JP, then it is better to add following
;; lines into .emacs, and it makes file encoding EUC.

(setq YaTeX-kanji-code 3)
(setq yahtml-kanji-code 3)

;;; yc site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/yc")

;;; zenburn site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/zenburn")
(autoload 'color-theme-zenburn "zenburn"
  "Just some alien fruit salad to keep you in the zone." t)
(defalias 'zenburn 'color-theme-zenburn)

;;; zenirc site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/zenirc")
(autoload 'zenirc  "zenirc" "Start ZenIRC" t)

;;; filladapt site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/filladapt")

;;; protbuf site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/protbuf")

(autoload 'protect-buffer-from-kill-mode "protbuf"
  "Protect buffer from being killed.
To remove this protection, call this command with a negative prefix argument."
  t)
(autoload 'protect-process-buffer-from-kill-mode "protbuf"
  "Protect buffer from being killed as long as it has an active process.
To remove this protection, call this command with a negative prefix argument."
  t)
(autoload 'protect-buffer-from-kill "protbuf")
(autoload 'protect-process-buffer-from-kill "protbuf")

;;; auctex site-lisp configuration, activating preview-latex

(load "preview-latex.el" nil t t)

;;; color-browser site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/color-browser")
(autoload 'color-browser "color-browser"
  "A utility for designing Emacs color themes" t)

(setq cb-palettes-dir "~/color-browser/palettes/")
(setq cb-themes-dir "~/color-browser/themes/")

;;; doctest-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/doctest-mode")
(autoload 'doctest-mode "doctest-mode"
  "Editing mode for Python Doctest examples." t)
(add-to-list 'auto-mode-alist '("\\.doctest\\'" . doctest-mode))

;;; flim site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/flim")

;;; moccur-edit site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/moccur-edit")
(eval-after-load "color-moccur"
  '(require 'moccur-edit))

;;; nxml-docbook5-schemas site-lisp configuration

;; This must be executed after rng-schema-locating-files
;; is set in rng-loc (which is part of nxml-mode).
(eval-after-load "rng-loc"
  '(add-to-list 'rng-schema-locating-files
		"/usr/share/emacs/etc/nxml-docbook5-schemas/schemas.xml"))

;;; nxml-gentoo-schemas site-lisp configuration

;; This must be executed after rng-schema-locating-files
;; is set in rng-loc (which is part of nxml-mode).
(eval-after-load "rng-loc"
  '(add-to-list 'rng-schema-locating-files
		"/usr/share/emacs/etc/nxml-gentoo-schemas/schemas.xml"))

;;; nxml-libvirt-schemas site-lisp configuration

;; This must be executed after rng-schema-locating-files
;; is set in rng-loc (which is part of nxml-mode).
(eval-after-load "rng-loc"
  '(add-to-list 'rng-schema-locating-files
		"/usr/share/emacs/etc/nxml-libvirt-schemas/schemas.xml"))

;;; nxml-svg-schemas site-lisp configuration

;; This must be executed after rng-schema-locating-files
;; is set in rng-loc (which is part of nxml-mode).
(eval-after-load "rng-loc"
  '(add-to-list 'rng-schema-locating-files
		"/usr/share/emacs/etc/nxml-svg-schemas/schemas.xml"))

;;; rudel site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/rudel")
(autoload 'rudel-join-session "rudel-loaddefs"
  "Start a collaborative Rudel session" t)
(autoload 'rudel-host-session "rudel-loaddefs"
  "Host a collaborative Rudel session" t)
(autoload 'rudel-speedbar "rudel-loaddefs"
  "Show connected users and documents for the Rudel session in speedbar" t)
(autoload 'global-rudel-minor-mode "rudel-loaddefs"
  "Bindings for rudel session-level commands" t)

;;(global-set-key (kbd "C-c c j") 'rudel-join-session)

(setq rudel-icons-directory "/usr/share/emacs/etc/rudel/icons/")

;;; scheme-complete site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/scheme-complete")
(autoload 'scheme-smart-complete "scheme-complete" nil t)
(autoload 'scheme-complete-or-indent "scheme-complete" nil t)
(autoload 'scheme-get-current-symbol-info "scheme-complete")

;;; semi site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/semi")
(require 'mime-setup)

;;; ecb site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/ecb")
(require 'ecb-autoloads)

;;; emacs-w3m site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/emacs-w3m")
(setq w3m-icon-directory "/usr/share/emacs/etc/emacs-w3m")
(require 'w3m-load)

;;; jde site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/jde")
(require 'jde-autoload)

(setq jde-java-directory "/usr/share/jde")
(setq jde-bsh-jar-file "/usr/share/bsh/lib/bsh.jar")
(setq jde-checkstyle-jar-file "//usr/share/checkstyle/lib/checkstyle.jar")
(setq jde-checkstyle-style "/usr/share/checkstyle/checks/sun_checks.xml")
(setq jde-html-directory "/usr/share/doc/jde-2.4.1-r1/html")
(setq bsh-html-directory "/usr/share/doc/jde-2.4.1-r1/html")
(setq jde-check-version-flag nil)

;;; mu site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/mu4e")
(require 'mu4e)


;;; slime site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/slime")
(add-to-list 'load-path "/usr/share/emacs/site-lisp/slime/contrib")
(autoload 'slime-highlight-edits-mode "slime-highlight-edits" nil t)

(require 'slime-autoloads)
(slime-setup '(slime-fancy slime-asdf slime-banner))

;; this allows us not to require dev-lisp/hyperspec
;; (which is non-free) as a hard dependency
(setq common-lisp-hyperspec-root
      (if (file-exists-p "/usr/share/doc/hyperspec/HyperSpec")
	  "file:///usr/share/doc/hyperspec/HyperSpec/"
	"http://www.lispworks.com/reference/HyperSpec/"))

;;; w3mnav site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/w3mnav")

(autoload 'w3m-nav-go-top "w3mnav" nil t)
(autoload 'w3m-nav-go-prev "w3mnav" nil t)
(autoload 'w3m-nav-go-next "w3mnav" nil t)

(add-hook 'w3m-mode-hook
	  (lambda ()
	    (setq w3m-mode-map w3m-info-like-map)
	    (define-key w3m-mode-map "t" 'w3m-nav-go-top)
	    (define-key w3m-mode-map "[" 'w3m-nav-go-prev)
	    (define-key w3m-mode-map "]" 'w3m-nav-go-next)))

;;; planner site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/planner")
(require 'planner-autoloads)
(setq remember-handler-functions '(remember-planner-append))
(defvaralias 'remember-annotation-functions 'planner-annotation-functions)


(provide 'site-gentoo)

;; Local Variables:
;; no-byte-compile: t
;; buffer-read-only: t
;; End:

;;; site-gentoo.el ends here
